@@ -643,8 +643,7 @@ class TpuClient(metaclass=TpuClientMeta):
 
         Args:
             request (Union[google.cloud.tpu_v1.types.GetNodeRequest, dict]):
-                The request object. Request for
-                [GetNode][google.cloud.tpu.v1.Tpu.GetNode].
+                The request object. Request for [GetNode][google.cloud.tpu.v1.Tpu.GetNode].
             name (str):
                 Required. The resource name.
                 This corresponds to the ``name`` field
@@ -1290,7 +1289,7 @@ class TpuClient(metaclass=TpuClientMeta):
         Returns:
             google.cloud.tpu_v1.services.tpu.pagers.ListTensorFlowVersionsPager:
                 Response for
-                [ListTensorFlowVersions][google.cloud.tpu.v1.Tpu.ListTensorFlowVersions].
+                   [ListTensorFlowVersions][google.cloud.tpu.v1.Tpu.ListTensorFlowVersions].
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -1505,7 +1504,7 @@ class TpuClient(metaclass=TpuClientMeta):
         Returns:
             google.cloud.tpu_v1.services.tpu.pagers.ListAcceleratorTypesPager:
                 Response for
-                [ListAcceleratorTypes][google.cloud.tpu.v1.Tpu.ListAcceleratorTypes].
+                   [ListAcceleratorTypes][google.cloud.tpu.v1.Tpu.ListAcceleratorTypes].
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
