@@ -370,8 +370,7 @@ class TpuAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.tpu_v2.types.GetNodeRequest, dict]]):
-                The request object. Request for
-                [GetNode][google.cloud.tpu.v2.Tpu.GetNode].
+                The request object. Request for [GetNode][google.cloud.tpu.v2.Tpu.GetNode].
             name (:class:`str`):
                 Required. The resource name.
                 This corresponds to the ``name`` field
@@ -1058,7 +1057,7 @@ class TpuAsyncClient:
         Returns:
             google.cloud.tpu_v2.types.GenerateServiceIdentityResponse:
                 Response for
-                [GenerateServiceIdentity][google.cloud.tpu.v2.Tpu.GenerateServiceIdentity].
+                   [GenerateServiceIdentity][google.cloud.tpu.v2.Tpu.GenerateServiceIdentity].
 
         """
         # Create or coerce a protobuf request object.
@@ -1145,7 +1144,7 @@ class TpuAsyncClient:
         Returns:
             google.cloud.tpu_v2.services.tpu.pagers.ListAcceleratorTypesAsyncPager:
                 Response for
-                [ListAcceleratorTypes][google.cloud.tpu.v2.Tpu.ListAcceleratorTypes].
+                   [ListAcceleratorTypes][google.cloud.tpu.v2.Tpu.ListAcceleratorTypes].
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -1358,7 +1357,7 @@ class TpuAsyncClient:
         Returns:
             google.cloud.tpu_v2.services.tpu.pagers.ListRuntimeVersionsAsyncPager:
                 Response for
-                [ListRuntimeVersions][google.cloud.tpu.v2.Tpu.ListRuntimeVersions].
+                   [ListRuntimeVersions][google.cloud.tpu.v2.Tpu.ListRuntimeVersions].
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -1564,7 +1563,7 @@ class TpuAsyncClient:
         Returns:
             google.cloud.tpu_v2.types.GetGuestAttributesResponse:
                 Response for
-                [GetGuestAttributes][google.cloud.tpu.v2.Tpu.GetGuestAttributes].
+                   [GetGuestAttributes][google.cloud.tpu.v2.Tpu.GetGuestAttributes].
 
         """
         # Create or coerce a protobuf request object.
