@@ -17,7 +17,7 @@
 import dataclasses
 import json  # type: ignore
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 from google.api_core import (
@@ -470,7 +470,7 @@ class TpuRestInterceptor:
         self,
         request: locations_pb2.GetLocationRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> locations_pb2.Location:
+    ) -> Tuple[locations_pb2.GetLocationRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for get_location
 
         Override in a subclass to manipulate the request or metadata
@@ -479,7 +479,7 @@ class TpuRestInterceptor:
         return request, metadata
 
     def post_get_location(
-        self, response: locations_pb2.GetLocationRequest
+        self, response: locations_pb2.Location
     ) -> locations_pb2.Location:
         """Post-rpc interceptor for get_location
 
@@ -493,7 +493,7 @@ class TpuRestInterceptor:
         self,
         request: locations_pb2.ListLocationsRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> locations_pb2.ListLocationsResponse:
+    ) -> Tuple[locations_pb2.ListLocationsRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for list_locations
 
         Override in a subclass to manipulate the request or metadata
@@ -502,7 +502,7 @@ class TpuRestInterceptor:
         return request, metadata
 
     def post_list_locations(
-        self, response: locations_pb2.ListLocationsRequest
+        self, response: locations_pb2.ListLocationsResponse
     ) -> locations_pb2.ListLocationsResponse:
         """Post-rpc interceptor for list_locations
 
@@ -516,7 +516,7 @@ class TpuRestInterceptor:
         self,
         request: operations_pb2.CancelOperationRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> None:
+    ) -> Tuple[operations_pb2.CancelOperationRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for cancel_operation
 
         Override in a subclass to manipulate the request or metadata
@@ -524,9 +524,7 @@ class TpuRestInterceptor:
         """
         return request, metadata
 
-    def post_cancel_operation(
-        self, response: operations_pb2.CancelOperationRequest
-    ) -> None:
+    def post_cancel_operation(self, response: None) -> None:
         """Post-rpc interceptor for cancel_operation
 
         Override in a subclass to manipulate the response
@@ -539,7 +537,7 @@ class TpuRestInterceptor:
         self,
         request: operations_pb2.DeleteOperationRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> None:
+    ) -> Tuple[operations_pb2.DeleteOperationRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for delete_operation
 
         Override in a subclass to manipulate the request or metadata
@@ -547,9 +545,7 @@ class TpuRestInterceptor:
         """
         return request, metadata
 
-    def post_delete_operation(
-        self, response: operations_pb2.DeleteOperationRequest
-    ) -> None:
+    def post_delete_operation(self, response: None) -> None:
         """Post-rpc interceptor for delete_operation
 
         Override in a subclass to manipulate the response
@@ -562,7 +558,7 @@ class TpuRestInterceptor:
         self,
         request: operations_pb2.GetOperationRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> operations_pb2.Operation:
+    ) -> Tuple[operations_pb2.GetOperationRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for get_operation
 
         Override in a subclass to manipulate the request or metadata
@@ -571,7 +567,7 @@ class TpuRestInterceptor:
         return request, metadata
 
     def post_get_operation(
-        self, response: operations_pb2.GetOperationRequest
+        self, response: operations_pb2.Operation
     ) -> operations_pb2.Operation:
         """Post-rpc interceptor for get_operation
 
@@ -585,7 +581,7 @@ class TpuRestInterceptor:
         self,
         request: operations_pb2.ListOperationsRequest,
         metadata: Sequence[Tuple[str, str]],
-    ) -> operations_pb2.ListOperationsResponse:
+    ) -> Tuple[operations_pb2.ListOperationsRequest, Sequence[Tuple[str, str]]]:
         """Pre-rpc interceptor for list_operations
 
         Override in a subclass to manipulate the request or metadata
@@ -594,7 +590,7 @@ class TpuRestInterceptor:
         return request, metadata
 
     def post_list_operations(
-        self, response: operations_pb2.ListOperationsRequest
+        self, response: operations_pb2.ListOperationsResponse
     ) -> operations_pb2.ListOperationsResponse:
         """Post-rpc interceptor for list_operations
 
@@ -759,7 +755,7 @@ class TpuRestTransport(TpuTransport):
         def __hash__(self):
             return hash("CreateNode")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -783,7 +779,6 @@ class TpuRestTransport(TpuTransport):
                 request (~.cloud_tpu.CreateNodeRequest):
                     The request object. Request for
                 [CreateNode][google.cloud.tpu.v2.Tpu.CreateNode].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -857,7 +852,7 @@ class TpuRestTransport(TpuTransport):
         def __hash__(self):
             return hash("DeleteNode")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -881,7 +876,6 @@ class TpuRestTransport(TpuTransport):
                 request (~.cloud_tpu.DeleteNodeRequest):
                     The request object. Request for
                 [DeleteNode][google.cloud.tpu.v2.Tpu.DeleteNode].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -946,7 +940,7 @@ class TpuRestTransport(TpuTransport):
         def __hash__(self):
             return hash("GenerateServiceIdentity")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -970,7 +964,6 @@ class TpuRestTransport(TpuTransport):
                 request (~.cloud_tpu.GenerateServiceIdentityRequest):
                     The request object. Request for
                 [GenerateServiceIdentity][google.cloud.tpu.v2.Tpu.GenerateServiceIdentity].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1047,7 +1040,7 @@ class TpuRestTransport(TpuTransport):
         def __hash__(self):
             return hash("GetAcceleratorType")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1071,7 +1064,6 @@ class TpuRestTransport(TpuTransport):
                 request (~.cloud_tpu.GetAcceleratorTypeRequest):
                     The request object. Request for
                 [GetAcceleratorType][google.cloud.tpu.v2.Tpu.GetAcceleratorType].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1139,7 +1131,7 @@ class TpuRestTransport(TpuTransport):
         def __hash__(self):
             return hash("GetGuestAttributes")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1163,7 +1155,6 @@ class TpuRestTransport(TpuTransport):
                 request (~.cloud_tpu.GetGuestAttributesRequest):
                     The request object. Request for
                 [GetGuestAttributes][google.cloud.tpu.v2.Tpu.GetGuestAttributes].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1240,7 +1231,7 @@ class TpuRestTransport(TpuTransport):
         def __hash__(self):
             return hash("GetNode")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1326,7 +1317,7 @@ class TpuRestTransport(TpuTransport):
         def __hash__(self):
             return hash("GetRuntimeVersion")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1350,7 +1341,6 @@ class TpuRestTransport(TpuTransport):
                 request (~.cloud_tpu.GetRuntimeVersionRequest):
                     The request object. Request for
                 [GetRuntimeVersion][google.cloud.tpu.v2.Tpu.GetRuntimeVersion].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1418,7 +1408,7 @@ class TpuRestTransport(TpuTransport):
         def __hash__(self):
             return hash("ListAcceleratorTypes")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1442,7 +1432,6 @@ class TpuRestTransport(TpuTransport):
                 request (~.cloud_tpu.ListAcceleratorTypesRequest):
                     The request object. Request for
                 [ListAcceleratorTypes][google.cloud.tpu.v2.Tpu.ListAcceleratorTypes].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1510,7 +1499,7 @@ class TpuRestTransport(TpuTransport):
         def __hash__(self):
             return hash("ListNodes")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1534,7 +1523,6 @@ class TpuRestTransport(TpuTransport):
                 request (~.cloud_tpu.ListNodesRequest):
                     The request object. Request for
                 [ListNodes][google.cloud.tpu.v2.Tpu.ListNodes].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1600,7 +1588,7 @@ class TpuRestTransport(TpuTransport):
         def __hash__(self):
             return hash("ListRuntimeVersions")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1624,7 +1612,6 @@ class TpuRestTransport(TpuTransport):
                 request (~.cloud_tpu.ListRuntimeVersionsRequest):
                     The request object. Request for
                 [ListRuntimeVersions][google.cloud.tpu.v2.Tpu.ListRuntimeVersions].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1692,7 +1679,7 @@ class TpuRestTransport(TpuTransport):
         def __hash__(self):
             return hash("StartNode")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1716,7 +1703,6 @@ class TpuRestTransport(TpuTransport):
                 request (~.cloud_tpu.StartNodeRequest):
                     The request object. Request for
                 [StartNode][google.cloud.tpu.v2.Tpu.StartNode].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1790,7 +1776,7 @@ class TpuRestTransport(TpuTransport):
         def __hash__(self):
             return hash("StopNode")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -1814,7 +1800,6 @@ class TpuRestTransport(TpuTransport):
                 request (~.cloud_tpu.StopNodeRequest):
                     The request object. Request for
                 [StopNode][google.cloud.tpu.v2.Tpu.StopNode].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1888,7 +1873,7 @@ class TpuRestTransport(TpuTransport):
         def __hash__(self):
             return hash("UpdateNode")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "updateMask": {},
         }
 
@@ -1914,7 +1899,6 @@ class TpuRestTransport(TpuTransport):
                 request (~.cloud_tpu.UpdateNodeRequest):
                     The request object. Request for
                 [UpdateNode][google.cloud.tpu.v2.Tpu.UpdateNode].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
