@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 from google.protobuf import field_mask_pb2  # type: ignore
@@ -55,6 +57,7 @@ __protobuf__ = proto.module(
         "Symptom",
         "GetGuestAttributesRequest",
         "GetGuestAttributesResponse",
+        "AcceleratorConfig",
         "ShieldedInstanceConfig",
     },
 )
@@ -377,6 +380,8 @@ class Node(proto.Message):
             to the TPU Node.
         shielded_instance_config (google.cloud.tpu_v2.types.ShieldedInstanceConfig):
             Shielded Instance options.
+        accelerator_config (google.cloud.tpu_v2.types.AcceleratorConfig):
+            The AccleratorConfig for the TPU Node.
     """
 
     class State(proto.Enum):
@@ -578,6 +583,11 @@ class Node(proto.Message):
         number=45,
         message="ShieldedInstanceConfig",
     )
+    accelerator_config: "AcceleratorConfig" = proto.Field(
+        proto.MESSAGE,
+        number=46,
+        message="AcceleratorConfig",
+    )
 
 
 class ListNodesRequest(proto.Message):
@@ -801,6 +811,8 @@ class AcceleratorType(proto.Message):
             The resource name.
         type_ (str):
             the accelerator type.
+        accelerator_configs (MutableSequence[google.cloud.tpu_v2.types.AcceleratorConfig]):
+            The accelerator config.
     """
 
     name: str = proto.Field(
@@ -811,6 +823,11 @@ class AcceleratorType(proto.Message):
         proto.STRING,
         number=2,
     )
+    accelerator_configs: MutableSequence["AcceleratorConfig"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message="AcceleratorConfig",
+    )
 
 
 class GetAcceleratorTypeRequest(proto.Message):
@@ -1171,6 +1188,45 @@ class GetGuestAttributesResponse(proto.Message):
     )
 
 
+class AcceleratorConfig(proto.Message):
+    r"""A TPU accelerator configuration.
+
+    Attributes:
+        type_ (google.cloud.tpu_v2.types.AcceleratorConfig.Type):
+            Required. Type of TPU.
+        topology (str):
+            Required. Topology of TPU in chips.
+    """
+
+    class Type(proto.Enum):
+        r"""TPU type.
+
+        Values:
+            TYPE_UNSPECIFIED (0):
+                Unspecified version.
+            V2 (2):
+                TPU v2.
+            V3 (4):
+                TPU v3.
+            V4 (7):
+                TPU v4.
+        """
+        TYPE_UNSPECIFIED = 0
+        V2 = 2
+        V3 = 4
+        V4 = 7
+
+    type_: Type = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=Type,
+    )
+    topology: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+
+
 class ShieldedInstanceConfig(proto.Message):
     r"""A set of Shielded Instance options.
 
