@@ -155,6 +155,134 @@ class ListNodesAsyncPager:
         return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
 
 
+class ListQueuedResourcesPager:
+    """A pager for iterating through ``list_queued_resources`` requests.
+
+    This class thinly wraps an initial
+    :class:`google.cloud.tpu_v2alpha1.types.ListQueuedResourcesResponse` object, and
+    provides an ``__iter__`` method to iterate through its
+    ``queued_resources`` field.
+
+    If there are more pages, the ``__iter__`` method will make additional
+    ``ListQueuedResources`` requests and continue to iterate
+    through the ``queued_resources`` field on the
+    corresponding responses.
+
+    All the usual :class:`google.cloud.tpu_v2alpha1.types.ListQueuedResourcesResponse`
+    attributes are available on the pager. If multiple requests are made, only
+    the most recent response is retained, and thus used for attribute lookup.
+    """
+
+    def __init__(
+        self,
+        method: Callable[..., cloud_tpu.ListQueuedResourcesResponse],
+        request: cloud_tpu.ListQueuedResourcesRequest,
+        response: cloud_tpu.ListQueuedResourcesResponse,
+        *,
+        metadata: Sequence[Tuple[str, str]] = ()
+    ):
+        """Instantiate the pager.
+
+        Args:
+            method (Callable): The method that was originally called, and
+                which instantiated this pager.
+            request (google.cloud.tpu_v2alpha1.types.ListQueuedResourcesRequest):
+                The initial request object.
+            response (google.cloud.tpu_v2alpha1.types.ListQueuedResourcesResponse):
+                The initial response object.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        """
+        self._method = method
+        self._request = cloud_tpu.ListQueuedResourcesRequest(request)
+        self._response = response
+        self._metadata = metadata
+
+    def __getattr__(self, name: str) -> Any:
+        return getattr(self._response, name)
+
+    @property
+    def pages(self) -> Iterator[cloud_tpu.ListQueuedResourcesResponse]:
+        yield self._response
+        while self._response.next_page_token:
+            self._request.page_token = self._response.next_page_token
+            self._response = self._method(self._request, metadata=self._metadata)
+            yield self._response
+
+    def __iter__(self) -> Iterator[cloud_tpu.QueuedResource]:
+        for page in self.pages:
+            yield from page.queued_resources
+
+    def __repr__(self) -> str:
+        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
+
+
+class ListQueuedResourcesAsyncPager:
+    """A pager for iterating through ``list_queued_resources`` requests.
+
+    This class thinly wraps an initial
+    :class:`google.cloud.tpu_v2alpha1.types.ListQueuedResourcesResponse` object, and
+    provides an ``__aiter__`` method to iterate through its
+    ``queued_resources`` field.
+
+    If there are more pages, the ``__aiter__`` method will make additional
+    ``ListQueuedResources`` requests and continue to iterate
+    through the ``queued_resources`` field on the
+    corresponding responses.
+
+    All the usual :class:`google.cloud.tpu_v2alpha1.types.ListQueuedResourcesResponse`
+    attributes are available on the pager. If multiple requests are made, only
+    the most recent response is retained, and thus used for attribute lookup.
+    """
+
+    def __init__(
+        self,
+        method: Callable[..., Awaitable[cloud_tpu.ListQueuedResourcesResponse]],
+        request: cloud_tpu.ListQueuedResourcesRequest,
+        response: cloud_tpu.ListQueuedResourcesResponse,
+        *,
+        metadata: Sequence[Tuple[str, str]] = ()
+    ):
+        """Instantiates the pager.
+
+        Args:
+            method (Callable): The method that was originally called, and
+                which instantiated this pager.
+            request (google.cloud.tpu_v2alpha1.types.ListQueuedResourcesRequest):
+                The initial request object.
+            response (google.cloud.tpu_v2alpha1.types.ListQueuedResourcesResponse):
+                The initial response object.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        """
+        self._method = method
+        self._request = cloud_tpu.ListQueuedResourcesRequest(request)
+        self._response = response
+        self._metadata = metadata
+
+    def __getattr__(self, name: str) -> Any:
+        return getattr(self._response, name)
+
+    @property
+    async def pages(self) -> AsyncIterator[cloud_tpu.ListQueuedResourcesResponse]:
+        yield self._response
+        while self._response.next_page_token:
+            self._request.page_token = self._response.next_page_token
+            self._response = await self._method(self._request, metadata=self._metadata)
+            yield self._response
+
+    def __aiter__(self) -> AsyncIterator[cloud_tpu.QueuedResource]:
+        async def async_generator():
+            async for page in self.pages:
+                for response in page.queued_resources:
+                    yield response
+
+        return async_generator()
+
+    def __repr__(self) -> str:
+        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
+
+
 class ListAcceleratorTypesPager:
     """A pager for iterating through ``list_accelerator_types`` requests.
 
