@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 from google.protobuf import duration_pb2  # type: ignore
@@ -66,6 +68,7 @@ __protobuf__ = proto.module(
         "GetGuestAttributesRequest",
         "GetGuestAttributesResponse",
         "SimulateMaintenanceEventRequest",
+        "AcceleratorConfig",
         "ShieldedInstanceConfig",
     },
 )
@@ -389,6 +392,8 @@ class Node(proto.Message):
         queued_resource (str):
             Output only. The qualified name of the
             QueuedResource that requested this Node.
+        accelerator_config (google.cloud.tpu_v2alpha1.types.AcceleratorConfig):
+            The AccleratorConfig for the TPU Node.
         shielded_instance_config (google.cloud.tpu_v2alpha1.types.ShieldedInstanceConfig):
             Shielded Instance options.
     """
@@ -588,6 +593,11 @@ class Node(proto.Message):
         proto.STRING,
         number=43,
     )
+    accelerator_config: "AcceleratorConfig" = proto.Field(
+        proto.MESSAGE,
+        number=44,
+        message="AcceleratorConfig",
+    )
     shielded_instance_config: "ShieldedInstanceConfig" = proto.Field(
         proto.MESSAGE,
         number=45,
@@ -627,7 +637,7 @@ class QueuedResource(proto.Message):
             The queueing policy of the QueuedRequest.
         state (google.cloud.tpu_v2alpha1.types.QueuedResourceState):
             Output only. State of the QueuedResource
-            request
+            request.
     """
 
     class Tpu(proto.Message):
@@ -1366,6 +1376,8 @@ class AcceleratorType(proto.Message):
             The resource name.
         type_ (str):
             The accelerator type.
+        accelerator_configs (MutableSequence[google.cloud.tpu_v2alpha1.types.AcceleratorConfig]):
+            The accelerator config.
     """
 
     name: str = proto.Field(
@@ -1376,6 +1388,11 @@ class AcceleratorType(proto.Message):
         proto.STRING,
         number=2,
     )
+    accelerator_configs: MutableSequence["AcceleratorConfig"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message="AcceleratorConfig",
+    )
 
 
 class GetAcceleratorTypeRequest(proto.Message):
@@ -1762,6 +1779,45 @@ class SimulateMaintenanceEventRequest(proto.Message):
     )
 
 
+class AcceleratorConfig(proto.Message):
+    r"""A TPU accelerator configuration.
+
+    Attributes:
+        type_ (google.cloud.tpu_v2alpha1.types.AcceleratorConfig.Type):
+            Required. Type of TPU.
+        topology (str):
+            Required. Topology of TPU in chips.
+    """
+
+    class Type(proto.Enum):
+        r"""TPU type.
+
+        Values:
+            TYPE_UNSPECIFIED (0):
+                Unspecified version.
+            V2 (2):
+                TPU v2.
+            V3 (4):
+                TPU v3.
+            V4 (7):
+                TPU v4.
+        """
+        TYPE_UNSPECIFIED = 0
+        V2 = 2
+        V3 = 4
+        V4 = 7
+
+    type_: Type = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=Type,
+    )
+    topology: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+
+
 class ShieldedInstanceConfig(proto.Message):
     r"""A set of Shielded Instance options.
 
